@@ -1,4 +1,4 @@
-# Copyright 2015 FUJITSU LIMITED
+# Copyright 2015-2017 FUJITSU LIMITED
 # (C) Copyright 2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
@@ -11,7 +11,7 @@
 # or implied. See the License for the specific language governing permissions and limitations under
 # the License.
 
-import logging
+from oslo_log import log as logging
 import psycopg2
 
 from monasca_notification.common.repositories.base import base_repo
@@ -40,7 +40,10 @@ class PostgresqlRepo(base_repo.BaseRepo):
             if self._pgsql is None:
                 self._connect_to_pgsql()
             cur = self._pgsql.cursor()
-            cur.execute(self._find_alarm_action_sql, (alarm['alarmDefinitionId'], alarm['newState']))
+            cur.execute(
+                self._find_alarm_action_sql,
+                (alarm['alarmDefinitionId'],
+                 alarm['newState']))
             for row in cur:
                 yield (row[0], row[1].lower(), row[2], row[3], row[4])
         except psycopg2.Error as e:
