@@ -16,10 +16,10 @@
 
 import requests
 import simplejson as json
+import urllib
 
 from debtcollector import removals
 from oslo_config import cfg
-from six.moves import urllib
 
 from monasca_notification.plugins import abstract_notifier
 
@@ -141,6 +141,7 @@ class HipChatNotifier(abstract_notifier.AbstractNotifier):
             self._log.exception("Error trying to send to hipchat on URL {}".format(url))
             return False
 
+
 hipchat_notifier_group = cfg.OptGroup(name='%s_notifier' % HipChatNotifier.type)
 hipchat_notifier_opts = [
     cfg.IntOpt(name='timeout', default=5, min=1),
